Documentation
¶
Index ¶
- type AddMeetingRegistrantRequest
- type AddMeetingRegistrantResponse
- type Client
- func (client Client) AddMeetingRegistrant(meetingId int, email string, firstName string, lastName string, address string, ...) (addMeetingRegistrantResponse AddMeetingRegistrantResponse, err error)
- func (client Client) CreateInstantMeetingWithDefaultOptions(meetingTopic, meetingAgenda, userName string) (createMeetingResponse CreateMeetingResponse, err error)
- func (client Client) CreateMeeting(userId string, topic string, meetingType int, startTime string, duration int, ...) (createMeetingResponse CreateMeetingResponse, err error)
- func (client Client) DeleteMeeting(meetingId int) (err error)
- func (client Client) GetMeeting(meetingId int) (getMeetingResponse GetMeetingResponse, err error)
- func (client Client) GetMeetingInvitation(meetingId int) (getMeetingInvitationResponse GetMeetingInvitationResponse, err error)
- func (client Client) GetMeetingRecording(meetingId string) (GetMeetingRecordingResponse, error)
- func (client Client) ListMeetingRegistrants(meetingId int) (apiResponse ListMeetingRegistrantsResponse, err error)
- func (client Client) ListMeetings(userId string) (apiResponse ListMeetingsAPIResponse, err error)
- func (client Client) ToggleMeetingRecording(meetingId string, action RecordAction) (err error)
- func (client Client) UpdateMeetingStatus(meetingId int, status string) (err error)
- type CreateMeetingRequest
- type CreateMeetingResponse
- type CustomQuestion
- type GetMeetingInvitationResponse
- type GetMeetingRecordingResponse
- type GetMeetingResponse
- type ListMeetingRegistrantsResponse
- type ListMeetingsAPIResponse
- type Meeting
- type MeetingRegistrant
- type RecordAction
- type Recurrence
- type Settings
- type ToggleMeetingRecordingRequest
- type UpdateMeetingStatusRequest
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AddMeetingRegistrantRequest ¶
type AddMeetingRegistrantRequest struct {
Email string `json:"email"`
FirstName string `json:"first_name"`
LastName string `json:"last_name"`
Address string `json:"address"`
City string `json:"city"`
Country string `json:"country"`
Zip string `json:"zip"`
State string `json:"state"`
Phone string `json:"phone"`
Industry string `json:"industry"`
Org string `json:"org"`
JobTitle string `json:"job_title"`
PurchasingTimeFrame string `json:"purchasing_time_frame"`
RoleInPurchaseProcess string `json:"role_in_purchase_process"`
NoOfEmployees string `json:"no_of_employees"`
Comments string `json:"comments"`
CustomQuestions []CustomQuestion `json:"custom_questions"`
}
type Client ¶
type Client struct {
// contains filtered or unexported fields
}
func (Client) AddMeetingRegistrant ¶
func (client Client) AddMeetingRegistrant(meetingId int, email string, firstName string, lastName string, address string, city string, country string, zip string, state string, phone string, industry string, org string, jobTitle string, purchasingTimeFrame string, roleInPurchaseProcess string, noOfEmployees string, comments string, customQuestions []CustomQuestion) (addMeetingRegistrantResponse AddMeetingRegistrantResponse, err error)
API Documentation https://marketplace.zoom.us/docs/api-reference/zoom-api/meetings/meetingregistrantcreate
func (Client) CreateInstantMeetingWithDefaultOptions ¶
func (client Client) CreateInstantMeetingWithDefaultOptions(meetingTopic, meetingAgenda, userName string) (createMeetingResponse CreateMeetingResponse, err error)
func (Client) CreateMeeting ¶
func (client Client) CreateMeeting(userId string, topic string, meetingType int, startTime string, duration int, scheduledFor string, timezone string, password string, agenda string, recurrence *Recurrence, settings *Settings) (createMeetingResponse CreateMeetingResponse, err error)
API Documentation https://marketplace.zoom.us/docs/api-reference/zoom-api/meetings/meetingcreate
func (Client) DeleteMeeting ¶
API Documentation https://marketplace.zoom.us/docs/api-reference/zoom-api/meetings/meetingdelete
func (Client) GetMeeting ¶
func (client Client) GetMeeting(meetingId int) (getMeetingResponse GetMeetingResponse, err error)
API Documentation https://marketplace.zoom.us/docs/api-reference/zoom-api/meetings/meeting
func (Client) GetMeetingInvitation ¶
func (client Client) GetMeetingInvitation(meetingId int) (getMeetingInvitationResponse GetMeetingInvitationResponse, err error)
API Documentation https://marketplace.zoom.us/docs/api-reference/zoom-api/meetings/meetinginvitation
func (Client) GetMeetingRecording ¶
func (client Client) GetMeetingRecording(meetingId string) (GetMeetingRecordingResponse, error)
func (Client) ListMeetingRegistrants ¶
func (client Client) ListMeetingRegistrants(meetingId int) (apiResponse ListMeetingRegistrantsResponse, err error)
API Documentation https://marketplace.zoom.us/docs/api-reference/zoom-api/meetings/meetingregistrants
func (Client) ListMeetings ¶
func (client Client) ListMeetings(userId string) (apiResponse ListMeetingsAPIResponse, err error)
API Documentation https://marketplace.zoom.us/docs/api-reference/zoom-api/meetings/meetings
func (Client) ToggleMeetingRecording ¶
func (client Client) ToggleMeetingRecording(meetingId string, action RecordAction) (err error)
type CreateMeetingRequest ¶
type CreateMeetingRequest struct {
Topic string `json:"topic"`
Type int `json:"type"`
StartTime string `json:"start_time"`
Duration int `json:"duration"`
ScheduleFor string `json:"schedule_for"`
Timezone string `json:"timezone"`
Password string `json:"password"`
Agenda string `json:"agenda"`
Recurrence *Recurrence `json:"recurrence"`
Settings *Settings `json:"settings"`
}
type CreateMeetingResponse ¶
type CreateMeetingResponse struct {
CreatedAt time.Time `json:"created_at"`
Duration int `json:"duration"`
HostId string `json:"host_id"`
Id int `json:"id"`
JoinUrl string `json:"join_url"`
Settings struct {
AlternativeHosts string `json:"alternative_hosts"`
ApprovalType int `json:"approval_type"`
Audio string `json:"audio"`
AutoRecording string `json:"auto_recording"`
CloseRegistration bool `json:"close_registration"`
CnMeeting bool `json:"cn_meeting"`
EnforceLogin bool `json:"enforce_login"`
EnforceLoginDomains string `json:"enforce_login_domains"`
GlobalDialInCountries []string `json:"global_dial_in_countries"`
GlobalDialInNumbers []struct {
City string `json:"city"`
Country string `json:"country"`
CountryName string `json:"country_name"`
Number string `json:"number"`
Type string `json:"type"`
} `json:"global_dial_in_numbers"`
HostVideo bool `json:"host_video"`
InMeeting bool `json:"in_meeting"`
JoinBeforeHost bool `json:"join_before_host"`
MuteUponEntry bool `json:"mute_upon_entry"`
ParticipantVideo bool `json:"participant_video"`
RegistrantsConfirmationEmail bool `json:"registrants_confirmation_email"`
UsePmi bool `json:"use_pmi"`
WaitingRoom bool `json:"waiting_room"`
Watermark bool `json:"watermark"`
RegistrantsEmailNotification bool `json:"registrants_email_notification"`
} `json:"settings"`
StartTime time.Time `json:"start_time"`
StartUrl string `json:"start_url"`
Status string `json:"status"`
Timezone string `json:"timezone"`
Topic string `json:"topic"`
Type int `json:"type"`
UUID string `json:"uuid"`
}
type CustomQuestion ¶
type GetMeetingInvitationResponse ¶
type GetMeetingInvitationResponse struct {
Invitation string `json:"invitation"`
}
type GetMeetingRecordingResponse ¶
type GetMeetingRecordingResponse struct {
UUID string `json:"uuid"`
ID int64 `json:"id"`
AccountID string `json:"account_id"`
HostID string `json:"host_id"`
Topic string `json:"topic"`
Type int `json:"type"`
StartTime time.Time `json:"start_time"`
Timezone string `json:"timezone"`
Duration int `json:"duration"`
TotalSize int `json:"total_size"`
RecordingCount int `json:"recording_count"`
RecordingFiles []struct {
ID string `json:"id"`
MeetingID string `json:"meeting_id"`
RecordingStart time.Time `json:"recording_start"`
RecordingEnd time.Time `json:"recording_end"`
FileType string `json:"file_type"`
FileExtension string `json:"file_extension"`
FileSize int `json:"file_size"`
PlayURL string `json:"play_url"`
DownloadURL string `json:"download_url"`
Status string `json:"status"`
RecordingType string `json:"recording_type"`
} `json:"recording_files"`
}
type GetMeetingResponse ¶
type GetMeetingResponse struct {
Agenda string `json:"agenda"`
CreatedAt time.Time `json:"created_at"`
Duration int `json:"duration"`
HostId string `json:"host_id"`
Id int `json:"id"`
JoinUrl string `json:"join_url"`
Settings struct {
AlternativeHosts string `json:"alternative_hosts"`
ApprovalType int `json:"approval_type"`
Audio string `json:"audio"`
AutoRecording string `json:"auto_recording"`
CloseRegistration bool `json:"close_registration"`
CnMeeting bool `json:"cn_meeting"`
EnforceLogin bool `json:"enforce_login"`
EnforceLoginDomains string `json:"enforce_login_domains"`
GlobalDialInCountries []string `json:"global_dial_in_countries"`
GlobalDialInNumbers []struct {
City string `json:"city"`
Country string `json:"country"`
CountryName string `json:"country_name"`
Number string `json:"number"`
Type string `json:"type"`
} `json:"global_dial_in_numbers"`
HostVideo bool `json:"host_video"`
InMeeting bool `json:"in_meeting"`
JoinBeforeHost bool `json:"join_before_host"`
MuteUponEntry bool `json:"mute_upon_entry"`
ParticipantVideo bool `json:"participant_video"`
RegistrantsConfirmationEmail bool `json:"registrants_confirmation_email"`
UsePmi bool `json:"use_pmi"`
WaitingRoom bool `json:"waiting_room"`
Watermark bool `json:"watermark"`
RegistrantsEmailNotification bool `json:"registrants_email_notification"`
} `json:"settings"`
StartTime time.Time `json:"start_time"`
StartUrl string `json:"start_url"`
Status string `json:"status"`
Timezone string `json:"timezone"`
Topic string `json:"topic"`
Type int `json:"type"`
Uuid string `json:"uuid"`
}
type ListMeetingRegistrantsResponse ¶
type ListMeetingRegistrantsResponse struct {
PageCount int `json:"page_count"`
PageNumber int `json:"page_number"`
PageSize int `json:"page_size"`
TotalRecords int `json:"total_records"`
Registrants []MeetingRegistrant `json:"registrants"`
}
type ListMeetingsAPIResponse ¶
type Meeting ¶
type Meeting struct {
Uuid string `json:"uuid"`
Id int `json:"id"`
HostId string `json:"host_id"`
Topic string `json:"topic"`
Type int `json:"type"`
StartTime time.Time `json:"start_time"`
Duration int `json:"duration"`
Timezone string `json:"timezone"`
CreatedAt time.Time `json:"created_at"`
JoinUrl string `json:"join_url"`
Agenda string `json:"agenda,omitempty"`
}
type MeetingRegistrant ¶
type MeetingRegistrant struct {
Email string `json:"email"`
FirstName string `json:"first_name"`
LastName string `json:"last_name"`
Id string `json:"id"`
Address string `json:"address"`
City string `json:"city"`
Country string `json:"country"`
Zip string `json:"zip"`
State string `json:"state"`
Phone string `json:"phone"`
Industry string `json:"industry"`
Org string `json:"org"`
JobTitle string `json:"job_title"`
PurchasingTimeFrame string `json:"purchasing_time_frame"`
RoleInPurchaseProcess string `json:"role_in_purchase_process"`
NoOfEmployees string `json:"no_of_employees"`
Comments string `json:"comments"`
CustomQuestion []CustomQuestion `json:"custom_questions"`
Status string `json:"status"`
CreateTime time.Time `json:"create_time"`
JoinUrl string `json:"join_url"`
}
type RecordAction ¶
type RecordAction string
var ( Start RecordAction = "recording.start" Stop RecordAction = "recording.stop" Pause RecordAction = "recording.pause" Resume RecordAction = "recording.resume" )
type Recurrence ¶
type Recurrence struct {
Type int `json:"type"`
RepeatInterval int `json:"repeat_interval"`
WeeklyDays string `json:"weekly_days"`
MonthlyDay int `json:"monthly_day"`
MonthlyWeek int `json:"monthly_week"`
MonthlyWeekDay int `json:"monthly_week_day"`
EndTimes int `json:"end_times"`
EndDateTime string `json:"end_date_time"`
}
type Settings ¶
type Settings struct {
HostVideo bool `json:"host_video"`
ParticipantVideo bool `json:"participant_video"`
CnMeeting bool `json:"cn_meeting"`
InMeeting bool `json:"in_meeting"`
JoinBeforeHost bool `json:"join_before_host"`
MuteUponEntry bool `json:"mute_upon_entry"`
Watermark bool `json:"watermark"`
UsePmi bool `json:"use_pmi"`
ApprovalType int `json:"approval_type"`
RegistrationType int `json:"registration_type"`
Audio string `json:"audio"`
AutoRecording string `json:"auto_recording"`
EnforceLogin bool `json:"enforce_login"`
EnforceLoginDomains string `json:"enforce_login_domains"`
AlternativeHosts string `json:"alternative_hosts"`
GlobalDialInCountries []string `json:"global_dial_in_countries"`
RegistrantsEmailNotification bool `json:"registrants_email_notification"`
}
type ToggleMeetingRecordingRequest ¶
type ToggleMeetingRecordingRequest struct {
Method string `json:"method"`
}
type UpdateMeetingStatusRequest ¶
type UpdateMeetingStatusRequest struct {
Action string `json:"action"`
}